import verify from "./src/verify.js";
import publish from "./src/publish.js";

let verified = false;

/**
 * A semantic-release plugin that creates truncated version tags in GitLab
 * using the GitLab API instead of Git commands.
 *
 * This plugin assumes that semantic-release creates the full version tag (e.g., v1.2.3)
 * and only focuses on creating/updating the truncated version tag (e.g., v1.2).
 */
export default {
  /**
   * Verify the plugin configuration and verify GitLab authentication
   */
  verifyConditions: async (pluginConfig, context) => {
    await verify(pluginConfig, context);
    verified = true;
  },

  /**
   * Publish release: Create the truncated tag in GitLab
   */
  publish: async (pluginConfig, context) => {
    return await publish(pluginConfig, context);
  }
};
